///////////////////////////////////////////////////////////////////////////////////////
// paDll.h
//
// 01/29/2001 - Changed parmaters to paSetSheetSize
// 01/30/2001 - Added error message PA_ERR_SHEET_NOT_FOUND
//              Added constants for SetPrinterCharacteristics
//              Added paSetOrientation
// 03/05/2001 - Reorganized
// 02/12/2002 - Start adding Language Monitor functions
// 04/17/2002 - Added refresh function to start Language monitor
// 10/10/2002 - Added bypass printer driver functions
// 01/03/2002 - Get paLMProgress function
// 15/16/2016 - Compiled for win32 and 64bit
// 12/05/2017 - Added paLMGetPrinterOKStatus2 and paLMRFIDPrinter
// 09/17/2018 - Added paGetDLLVersion
// 10/16/2018 - Added paLMPtrGetStatus
//              Added paLMPtrRFIDPrinter
//              Added paLMPtrIsPipe
//
///////////////////////////////////////////////////////////////////////////////////////

#ifndef __padll
#define __padll


///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////
// type of status desired
#define PA_STAT_SHORT		    0
#define PA_STAT_NORMAL		    1
#define PA_STAT_EXTENDED	    2
#define PA_STAT_COUNT		    3
#define PA_STAT_TEMPERATURE	    4
#define PA_STAT_FORMLENGTH	    5
#define PA_STAT_COMPLETE	    6
#define PA_STAT_LAST            7
#define PA_STAT_DOC_IN_PROGRESS 8

#define PA_RAW_STATUS_MAX_LENGTH 128   // Max size of pa raw status

// return codes from DLL functions
#define PA_ERR				     	0xc000
#define PA_ERR_OK				    0
#define PA_ERR_BAD_PRINTER_NAME	    (PA_ERR + 1)
#define PA_ERR_BAD_PORT_NAME	    (PA_ERR + 2)	
#define PA_ERR_SYSTEM			    (PA_ERR + 3)	// user must use GetLastError()
#define PA_ERR_VAL_NOT_SET		    (PA_ERR + 4)
#define PA_ERR_STRING_TOO_LONG	    (PA_ERR + 5)	
#define PA_ERR_PARAM1			    (PA_ERR + 6)
#define PA_ERR_PARAM2			    (PA_ERR + 7)
#define PA_ERR_PARAM3			    (PA_ERR + 8)
#define PA_ERR_PARAM4			    (PA_ERR + 9)
#define PA_ERR_NO_PRINTER_CHANGE	(PA_ERR + 10)
#define PA_ERR_ACCESS			    (PA_ERR + 11)
#define PA_ERR_NO_PRINTERS		    (PA_ERR + 12)
#define PA_ERR_REASSIGN			    (PA_ERR + 13)
#define PA_ERR_BLOWN_POINTER	    (PA_ERR + 14)
#define PA_ERR_OS_UNSUPPORTED	    (PA_ERR + 15)
#define PA_ERR_PORT_BUSY		    (PA_ERR + 16)
#define PA_ERR_BAD_STAT_GROUP	    (PA_ERR + 17)
#define PA_ERR_BAD_STAT_FIELD	    (PA_ERR + 18)
#define PA_ERR_BUFFER_TOO_SMALL	    (PA_ERR + 19)
#define PA_ERR_INSUFFICIENT_MEM	    (PA_ERR + 20)
#define PA_ERR_UNKNOWN_PRINTER	    (PA_ERR + 21)
#define PA_ERR_PORT_HAS_SPOOLED_JOB (PA_ERR + 22)
#define PA_ERR_SHEET_NOT_FOUND      (PA_ERR + 23)
#define PA_ERR_BIN_NOT_FOUND        (PA_ERR + 24)

// Error codes for language monitor
#define PA_ERR_PIPE_OPEN_BUSY          (PA_ERR + 25)
#define PA_ERR_PIPE_OPEN_FAILED        (PA_ERR + 26)
#define PA_ERR_PIPE_TIMEOUT            (PA_ERR + 27)
#define PA_ERR_PRINTER_NOT_RESPONDING  (PA_ERR + 28)
#define PA_ERR_STATUS_TIMEOUT          (PA_ERR + 29)

// Error codes for programatic flash update
#define PA_ERR_PRINTER_NOT_READY       (PA_ERR + 31)
#define PA_ERR_BIN_FILE_NOT_FOUND      (PA_ERR + 32)
#define PA_ERR_BIN_FILE_BAD_EXTENSION  (PA_ERR + 33)
#define PA_ERR_CAN_NOT_GET_MODEL       (PA_ERR + 34)
#define PA_ERR_STATUS_READ_ERROR       (PA_ERR + 35)
#define PA_ERR_INCORRECT_BIN_FILE      (PA_ERR + 36)
#define PA_ERR_FLASH_NOT_ENTERED       (PA_ERR + 37)
#define PA_ERR_FLASH_BAD_BIN_FILE      (PA_ERR + 38)
#define PA_ERR_FLASH_REPROGRAM_FAILED  (PA_ERR + 39)
#define PA_ERR_MODEL_NOT_FOUND         (PA_ERR + 40)

#define PA_ERR_UNKNOWN_KEY             (PA_ERR + 41)  // 1.10 Build 5


// Masks for evaluating parsed status
// the order is important, high bit to low
#define 	IDC_STATIC_80H   0x8000  // System Not Ready
#define 	IDC_STATIC_40H   0x4000  // Sys/Diag Error
#define 	IDC_STATIC_20H   0x2000  // Manual Deselect
#define 	IDC_STATIC_10H   0x1000  // Output Jam
#define 	IDC_STATIC_08H   0x0800  // Paper Reg. Error
#define 	IDC_STATIC_04H   0x0400  // Cutter Jam
#define 	IDC_STATIC_02H   0x0200  // Head Lever Up
#define 	IDC_STATIC_01H   0x0100  // Out of Paper

#define 	IDC_STATIC_80H2  0x0080  // Doc in Process
#define 	IDC_STATIC_40H2  0x0040  // Data 0 = data error, 1 = purge occurred
#define 	IDC_STATIC_20H2  0x0020  // Busy
#define 	IDC_STATIC_10H2  0x0010  // PH Temp Wait
#define 	IDC_STATIC_08H2  0x0008  // Ticket Not Taken
#define 	IDC_STATIC_04H2  0x0004  // Avg. Power Wait
#define 	IDC_STATIC_02H2  0x0002  // Dispose Toggle Flag
#define 	IDC_STATIC_01H2  0x0001  // Low Paper

// Defines for legal paper bins GTX printer series
#define PA_CUT_ALL     "Cut on all pages"
#define PA_CUT_2ND     "Cut every 2nd page"
#define PA_CUT_3RD     "Cut every 3rd page"
#define PA_CUT_4TH     "Cut every 4th page"
#define PA_CUT_5TH     "Cut every 5th page"
#define PA_CUT_LAST    "Cut on last page only"
#define PA_NO_CUT      "Disable cutting"

// Defines for RFID
#define RFID_READER_NOT_DETERMINED	0x30    // Reader presence unknown
#define RFID_NO_READER				0x31	// No reader installed
#define RFID_READER_NON_FUNCTIONAL	0x32	// Reader installed, but not functional
#define RFID_NO_STOCK				0x33    // Reader present, stock is OOP
#define RFID_TAGLESS_STOCK			0x34    // Non-RFID stock present.
#define RFID_STOCK_LOADED			0x35    // RFID stock present, but not ready
#define RFID_TAG_READY				0x36    // RFID Tag in position for reading/writing
#define RFID_TAG_FAULTY				0x37    // cannot read a tag which should be there

#define RFID_SUCCESS				0x30    // Operation complete; command specific data may follow
#define RFID_BUSY					0x31    // Operation still in process
#define RFID_FAILURE				0x32    // Operation failed
#define RFID_CANCELLING				0x33    // A cancel command is in process
#define RFID_CANCELLED				0x34    // A cancel operation is complete
#define RFID_NO_STATUS				0x35    // No operation is in process for this query
#define RFID_INVALID_COMMAND		0x36    // Command and/or parameters invalid


// Structure used when enumerating Sheet Names (and IDs)
#define SHEET_NAME_SIZE 64
typedef struct
{
	char	achName[SHEET_NAME_SIZE];
}SHEET_NAMES, *PSHEET_NAMES;

// Structure used when enumerating Bin Names (and IDs)
#define BIN_NAME_SIZE 24
typedef struct
{
	char	achName[BIN_NAME_SIZE];
}BIN_NAMES, *PBIN_NAMES;

// Structure used when parsing printer status
typedef struct{
	LONG	lStatBits;		    //field 00
	LONG	lError;
	LONG	lDocCount;
	LONG	lTemp_C;
	LONG	lTemp_F;
	LONG	lFormLen;			//field 04
	CHAR	type[2];			// C or E or A etc
	CHAR	chFormLen[16];		//field 04
	CHAR	chTemperature[4];	//field 03
	CHAR	chDocCount[9];		//field 02
	CHAR	chError[4];			//field 01
	CHAR	chStatBits[8];		//field 00
	CHAR	version[64];		//field 05
	CHAR	ver[16];			// ver  part of field 05
	CHAR	ver_date[16];		// date part of field 05
	//
} STATUS, *PSTATUS;


// Structure used when parsing flash upload status
typedef struct{
	DWORD   state;              // 0 = initial delay, 1 = sending data, 2 = end delay, 3 = complete
	DWORD   max;                // Maximum value for this state
	DWORD   current;            // Current value for this state
	char    PassFail;           // Pass 'P' or Faile 'F'
	char    note[1024];         // Reason for failure or final version
	//
}   FLASH_PROGRESS, *PFLASH_PROGRESS;


///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////




// Following copied from NTDDPAR.H. These constants are used by the DLL to
// interpret the results of the deviceIoCtl call for parallel Centronics status
#define PARALLEL_INIT            0x1
#define PARALLEL_AUTOFEED        0x2
#define PARALLEL_PAPER_EMPTY     0x4
#define PARALLEL_OFF_LINE        0x8
#define PARALLEL_POWER_OFF       0x10
#define PARALLEL_NOT_CONNECTED   0x20
#define PARALLEL_BUSY            0x40
#define PARALLEL_SELECTED        0x80



// high byte bits, 4th of 5 returned by most status commands
#define PA_PRINTER_NOT_READY		0x80	// see the User Manual defs
#define PA_PRINTER_SYSERROR			0x40
#define PA_PRINTER_MAN_DESELECT		0x20
#define PA_PRINTER_OUTPUT_JAM		0x10
#define PA_PRINTER_REGISTRATION		0x08
#define PA_PRINTER_CUTTER_JAM		0x04
#define PA_PRINTER_HEAD_LEVER_UP	0x02
#define PA_PRINTER_OUT_OF_PAPER		0x01

// low byte bits, 5th of 5 returned by most status commands
#define PA_PRINTER_DOC_IN_PROCESS   0x80
#define PA_PRINTER_DATA_ERROR		0x40    
#define PA_PRINTER_BUSY				0x20
#define PA_PRINTER_TEMP_WAIT		0x10
#define PA_PRINTER_TICKET_NOT_TAKEN	0x08
#define PA_PRINTER_AVG_POWER_WAIT	0x04
#define PA_PRINTER_DISPOSE_TOGGLE	0x02
#define PA_PRINTER_LOW_PAPER		0x01



// Internal use by DLL to direct the action of SetPrinterCharacteristics
#define PA_SET_PAPER_SIZE           0x01
#define PA_SET_ORIENTATION          0x02
#define PA_SET_BIN                  0x03
#define PA_REFRESH                  0x04

typedef struct
{
	int		cx;
	int		cy;
	int		iPaperID;
	int		iOrient;
	HDC		hdc;
	HFONT	hfCurr;
	HFONT	hfPrev;
	int		iSaveDC;
	DOCINFO	di;
} DOC, *PDOC;

typedef struct
{
	char	chName[32];
	UINT	uId;
	float	fLen;	// these are in 10ths of mm. Divide by 254 for inches
	float	fWid;
	LONG	lLen;	// these are in 10ths of mm. Divide by 254 for inches
	LONG	lWid;
}
PA_FORM, *PPA_FORM;

#define	PA_MAX_FORMS	100

enum {
	PA_ATX23, PA_ATX24, PA_ETX, PA_ATX38, PA_GTX2002,
	PA_GTX2003, PA_GTX3004A_2, PA_GTX3004A_4, PA_GTX3002_3_4, PA_UNKNOWN = -1
};

#define MAX_MODELS 8		

#define FX_ETCH		2
#define FX_EMBOSS	3

typedef DWORD   COLORREF;
typedef DWORD   *LPCOLORREF;

#define ASCII_NUM	0
#define ASCII_TEXT	1
#define BINARY		2
typedef struct{
	WORD	wLen;	// -1 if variable length
	BYTE	bFormat;
} STAT_FIELD, *PSTAT_FIELD;


//////////////////////////////////////////////////////////////////////////////////////
// function prototypes 
//////////////////////////////////////////////////////////////////////////////////////

LRESULT APIENTRY paDeterminePrinterType(LPSTR pPrnName,
	PWORD piModel);

LRESULT APIENTRY paEnumPrinters(PVOID pInfoStructure,
	LONG lSize,
	LONG lLevel,
	PLONG plNeeded,
	PLONG pdwFound);

LRESULT APIENTRY paEnumSheetSizes(PVOID pSheetNames,
	PVOID pSheetID,
	PLONG plSheetsFound);

LRESULT APIENTRY paEnumBins(PVOID pBinNames,
	PVOID pBinNumbers,
	PLONG plBinsFound);


LRESULT APIENTRY paAcquirePort(PSZ pszPrinter);

LRESULT APIENTRY paReleasePort(void);

LRESULT APIENTRY paGetStatus(LONG lType,
	PUCHAR pBuffer,
	LONG lBuffLen,
	PLONG plRead);

LRESULT APIENTRY paGetStatus_NT_2K_XP(LONG lType,
	PUCHAR pBuffer,
	LONG lBuffLen,
	PLONG plRead);

LRESULT APIENTRY paGetAddStatus_NT_2K_XP
(LPSTR pStatusReqString,
PUCHAR pBuffer,
LONG lBuffLen,
PLONG plRead);

LRESULT APIENTRY paParseStatus(PUCHAR pStatus,
	LONG lLen,
	PSTATUS pStat);

LRESULT APIENTRY paSetBinByBinName(LPSTR pBinName);


STDAPI_(LONG) paFindMaxFont(HDC hdc,
	LONG dx,
	LONG dy,
	PVOID pFontName,
	PLOGFONT plf);

STDAPI_(LONG) paFontFX(HDC hdc,
	RECT *rcl,
	CHAR *txt,
	INT iFX, // int
	COLORREF crText,
	COLORREF crOutline);

LRESULT APIENTRY paGetDefaultPrinter(PAGESETUPDLG *psd);

LRESULT APIENTRY paGetHDC(PAGESETUPDLG *psd,
	HDC *pHDC);

LRESULT APIENTRY paGetOSVersion(OSVERSIONINFO * pOS,
	PSZ *pszOS);

LRESULT APIENTRY paGetPaperSizeInfo(LPSTR pPrinterName,
	LPSTR pPort,
	PWORD cFound);

LRESULT APIENTRY paGetPrinterModel(PWORD piModel);

LRESULT APIENTRY paGetPrinterNameAndPort(PAGESETUPDLG *psd,
	PSZ pName, LONG *cName,
	PSZ pPort, LONG *cPort,
	PSZ pDriver, LONG *cDriver);

LRESULT APIENTRY paMakeDocDC(INT iOrient,
	FLOAT fPaperSize,
	INT OutBinOption,
	PDOC pdoc,
	PAGESETUPDLG *psd,
	HDC *pHDC);

LRESULT APIENTRY paMakeUpperCase(PSZ pTarget,
	PSZ pSource);

LRESULT APIENTRY paSetBinByBinID(WORD binID);


LRESULT APIENTRY paSetPrinterModel(WORD wModel);

LRESULT APIENTRY paSetSheetSize(PFLOAT width,
	PFLOAT length);

LRESULT APIENTRY paSetVB(BOOL);

LRESULT APIENTRY paSetOrientation(SHORT orientationID);

LRESULT APIENTRY paSetNTPort(byte port_number);
LRESULT APIENTRY paSetNTPortAscii(char * pPortName);


LRESULT APIENTRY paProgramFlash(LPSTR  pFlashFile, BOOL Mode, LPSTR  pNewVersion, DWORD NewVersionLength, BOOL diagnostics);

LRESULT APIENTRY paLMProgramFlash
(LPSTR FileName,
BOOL Mode,
LPSTR pResultString,
DWORD dwResultStringLength);

LRESULT APIENTRY paLMGetProgress
(LPSTR   ProgressType,
PUCHAR  pResultString,
DWORD   dwResultStringLength,
DWORD * ResultBufferRead);

LRESULT APIENTRY paLMParseFlashProgress(LPSTR pRawFlashProgress, PFLASH_PROGRESS pFlashProgress);

/******************************************************************************/
// Language Monitor functions
/******************************************************************************/
LRESULT APIENTRY paLMOpenPipe(char * pipeName, DWORD dwTimeOut);
BOOL    APIENTRY paLMClosePipe(void);

BOOL APIENTRY paLMSetPipeName(char  * pszPipeName);
BOOL APIENTRY paLMSetPipeTimeOut(DWORD PipeTimeOut);
BOOL APIENTRY paLMSetStatusTimeOut(DWORD StatusTimeOut);

LRESULT APIENTRY
paLMGetStatus
(DWORD   dwType,                 // Status type 0 - 7 
BYTE  * pResultBuffer,          // Pointer to result buffer
DWORD   dwResultBufferLength,   // Length of result buffer
DWORD * pdwResultBufferRead);   // Number of status bytes read

LRESULT APIENTRY
paLMGetAddStatus
(char  * pStatusReqString,       // Pointer to status request string 
BYTE  * pResultBuffer,          // Pointer to result buffer
DWORD   dwResultBufferLength,   // Length of result buffer
DWORD * pdwResultBufferRead);   // Number of status bytes read


LRESULT APIENTRY
paLMGetPrinterName
(BYTE  * pResultBuffer,          // Pointer to result buffer
DWORD   dwResultBufferLength,   // Length of result buffer
DWORD * pdwResultBufferRead);   // Number of status bytes read

LRESULT APIENTRY
paLMGetPortName
(BYTE  * pResultBuffer,          // Pointer to result buffer
DWORD   dwResultBufferLength,   // Length of result buffer
DWORD * pdwResultBufferRead);   // Number of status bytes read

LRESULT APIENTRY
paLMGetLMVersion
(BYTE  * pResultBuffer,           // Pointer to result buffer
DWORD   dwResultBufferLength,    // Length of result buffer
DWORD * pdwResultBufferRead);    // Number of status bytes read

LRESULT APIENTRY
paLMSetHeartBeat
(BOOL    heartBeatOnOff);        // True = heart beat on, False = heartbeat off 

LRESULT APIENTRY
paLMSetHeartBeatRate
(DWORD   heartBeatRate);         // Rate in MS 

LRESULT APIENTRY
paLMSetSpoolerSaveMethod
(BYTE    method);                // 0 - 255 

LRESULT APIENTRY paLMRefresh(void); // To start up the LM

BOOL APIENTRY paLMIsPipe(void);

LRESULT APIENTRY
paLMGetHeadLeverOpenStatus(BOOL * pbHeadLeverOpenStatus);

LRESULT APIENTRY
paLMGetOutOfPaperStatus(BOOL * pbOutOfPaperStatus);

LRESULT APIENTRY
paLMGetLowPaperStatus(BOOL * pbLowPaperStatus);

LRESULT APIENTRY
paLMGetManDeselectStatus(BOOL * pbManDeselectStatus);

LRESULT APIENTRY
paLMGetJamStatus(BOOL * pbJamStatus);

LRESULT APIENTRY
paLMGetTicketNotTakenStatus(BOOL * pbTicketNotTakenStatus);

LRESULT APIENTRY
paLMGetPrinterOKStatus(BOOL * pbPrinterOKStatus);

LRESULT APIENTRY
paLMGetPrinterOKStatus2(BOOL * pbPrinterOKStatus);

LRESULT APIENTRY
paLMGetCRCError(BOOL * pbCRCError);

LRESULT APIENTRY paLMClearCRCError();

LRESULT APIENTRY
paLMWDSetup
(BOOL   bEnableWd,
BOOL   bResetOnCRC,
BYTE   bytePrintingTimeout,
BYTE   byteHBTimeout);

LRESULT APIENTRY
paLMGetPrintInProgress(BOOL  * pbPrintInProgressStatus);

BOOL APIENTRY paSetNewPrinter(char  * pszNewPrinterName);

LRESULT APIENTRY paLMAbortDocument(void);

LRESULT APIENTRY paGetSpoolingStatus(BOOL * spoolerStatus);

BOOL APIENTRY paPulseCashDrawerGPrinter(void);


/******************************************************************************/
// Bypass printer driver functions
/******************************************************************************/
BOOL APIENTRY paPrintBypassOpenPrinter(char  * pszDocumentName);
BOOL APIENTRY paPrintBypassWritePrinter(BYTE * pBytes, DWORD lLen);
BOOL APIENTRY paPrintBypassClosePrinter(void);
BOOL APIENTRY paPrintBypassPrintDocument(char  * pszDocumentName, BYTE * pBytes, DWORD dwCount);


/******************************************************************************/
// RFID Printer command added 11/23/2017
/******************************************************************************/
LRESULT APIENTRY paLMRFIDPrinter(char *pDataToWrite, DWORD lNoBytesToWrite, char *pResponseBytes, DWORD lMaxResponseLen, DWORD *plNoBytesRead, DWORD lTimeout);


/******************************************************************************/
// LM Printer Targeted Command added (10/10/2018 - V2.0.0.9)
/******************************************************************************/
LRESULT APIENTRY paLMPtrGetStatus(char *pszPrinterName, DWORD dwType, BYTE *pResultBuffer, DWORD dwResultBufferLength, DWORD *pdwResultBufferRead);
LRESULT APIENTRY paLMPtrRFIDPrinter(char *pszPrinterName, char *pDataToWrite, DWORD lNoBytesToWrite, char *pResponseBytes, DWORD lMaxResponseLen, DWORD *plNoBytesRead, DWORD lTimeout);
BOOL APIENTRY paLMPtrIsPipe(char *pszPrinterName);


/******************************************************************************/
// Get defaults added V1.09 B01 01/10/2006
/******************************************************************************/
LRESULT APIENTRY paNewGetDefaultPrinter(char * pPrinterName, DWORD * pdwBufferSize);
LRESULT APIENTRY paNewGetPrinterPort(LPSTR printerName, LPSTR printerPort);
LRESULT APIENTRY paNewGetPrinterDriver(LPSTR printerName, LPSTR printerDriver);

/******************************************************************************/
// SetRegistryKey added V1.10 B01 05/15/2007
/******************************************************************************/
LRESULT APIENTRY
paLMSetRegistryKey
(LPSTR RegistryKeyName,       // Name of registry key to update 
DWORD RegistryValue,         // DWORD value to set
LPSTR pResultString,         // Pointer to result string
DWORD dwResultStringLength,  // Result string length
DWORD * pResultBufferRead);  // Where number of bytes returned



/******************************************************************************/
// SetRegistryKey added V1.10 B05 11/12/2007
/******************************************************************************/
LRESULT APIENTRY paSetPrinterKeyByName(LPSTR printerKeyName, DWORD printerKeyValue);

/******************************************************************************/
// paLMGetDriverVersion added V1.10 B01 05/23/2007
/******************************************************************************/

BOOL APIENTRY
paLMGetDriverVersion(
char  * pszPrinterName,          // Name of printer to get version
char  * pszPrinterVersion,       // Pointer to result buffer
DWORD   dwPrinterVersionBufferLength,    // Length of result buffer
DWORD * pdwResultBufferRead);     // Number of bytes read


LRESULT APIENTRY
paLMResetPrinter(void);                  // Hard reset printer (USB only)


/******************************************************************************/
// paGetDLLVersion added V2.0.0.5 09/17/2018
/******************************************************************************/

BOOL APIENTRY
paGetDLLVersion(
char *pszDLLVersionBuffer,          // Buffer to contain DLL version
DWORD dwDLLVersionBufferLength,    // size if buffer in bytes
DWORD *pdwResultBufferRead);        // Number of bytes read



/******************************************************************************/
// VB-specific
/******************************************************************************/
STDAPI_(BSTR) paGetStringFromLPSTR(LPSTR tptr);

STDAPI_(VOID) paCopyData(LPVOID source, LPVOID dest, DWORD size);

STDAPI_(LONG) paGetAddressForObject(LPVOID lpobject);

// NT only (Not supported on 98
LRESULT APIENTRY paGetCentronicsStatus(PSZ pszPort, UCHAR *uchBits);

/******************************************************************************/
/* Font create and select functions VB and C
/******************************************************************************/
HFONT APIENTRY paCreateFont(HDC DeviceContext, char * FontName);
LRESULT APIENTRY paTextOut(HDC deviceContext, int Xpos, int Ypos, char *textToWrite);
HGDIOBJ APIENTRY paSelectObject(HDC PrinterHdc, HGDIOBJ NewFont);
BOOL APIENTRY paDeleteObject(HGDIOBJ FontToDelete);

/* strictly local jobs */
// BOOL bIsPrinter(LPSTR pszName);
BOOL paIsNT(VOID);
HANDLE	OpenPortUSB(TCHAR *devname);


STDAPI_(LONG) DllRegisterServer();
STDAPI_(LONG) DllUnregisterServer();

#endif
